Repository navigation
Sort option
sort is the main function of TAPES. It will prioritise variants and generate reports.
-i or --input
The input file will always be an ANNOVAR annotated file. It can be either:
- A vcf file (multi or single sample)
- A txt (tab separated) or csv (comma separated) file (ANNOVAR does not keep genotyping data in those format but you can use TAPES to annotate you original vcf files to the format of your liking)
-o or --output
The output file can be:
- a txt (tab separated) or csv (comma separated) accompanied by an xlsx file
- a folder containing either multiple txt (tab separated) or csv (comma separated) files.
python3 tapes.py sort -i /path/to/annotated_file.vcf -o /path/to/output.txt for txt+xlsx output
python3 tapes.py sort -i /path/to/annotated_file.vcf -o /path/to/output.csv for csv+xlsx output
python3 tapes.py sort -i /path/to/annotated_file.vcf -o /path/to/output/ for folder csv output
python3 tapes.py sort -i /path/to/annotated_file.vcf -o /path/to/output/ --tab for folder txt output
python3 tapes.py sort -i /path/to/annotated_file.vcf -o /path/to/output/ --tab --acmg --by_sample --by_gene --enrichr --disease "autosomal dominant" --kegg "Pathways in cancer" --list "ATM APC MUTYH AKT1 CASP8 DMD MSH3 MSH6 MLH1 MSH2 POLE POLD POLQ KRAS" -a hg19 --BIG --trio ./trio.txt
The different reports generated (if using the FOLDER mode) will have different suffixes appended to them. For example:
- report_by_sample.txt for the
--by_sampleoption - report_GO_Biological_Process_2018.txt for the
--enrichroption using the GO_Biological_Process_2018 library
-
-a--assembly|string| The assembly used. Either hg19 or hg38 - default is hg19 -
--acmg|flag| Will check for all necessary annotations before proceeding. Will exit the program if alle the necessary annotations were not found. Do not use this unless your annotation file is fully "TAPES compliant" -
--BIG|0 to 1 float|If your file is particularly big, remove variants that are not likely to be pathogenic from the output.Take the percentage of chance to be pathogenic as an argument - default = 0.35 -
--by_gene|flag| Will generate a report of the mutational burden for each gene with associated samples for each variant. -
--by_sample|flag|Will generate a report grouping all pathogenic variants per sample -
--cutoff|0 to 1 float| Select the cutoff for "rare" variant. Used in ACMG BS1 - default = 0.005 -
-d--disease|string| Will generate a report similar to the main report including only the variants involved in a particular disease. Based on the Disease column from ANNOVAR - default = "cancer" -
-e--enrichr|string| Implementation of the EnrichR API. Analyse top mutations (>0.85 in Pathology prediction) with EnrichR API to determine the pathways disrupted by pathogenic variants - default = GO_Biological_Process_2018 - See the EnrichR librairies page for the full list of available EnrichR Libraries -
--kegg|string|Similar to list but if you do not know all the genes involved in a given pathway. Will generate a report similar to the main report including only variants found in the genes related to a given pathway. See the KEGG pathways page for the full list of available pathways -
--list|string or path| Will generate a report similar to the main report including only variants found in genes list. Using gene symbols. Can use either a string containing gene symbols separated by a space and in quotes(eg. "MLH1 APC MLH2 BRCA2 PTEN") or a txt file with one gene symbol per line -
-t--threads|int| Number of threads to use for sorting | Still not optimised and require a large amount of ram ( around 2Gb per thread + 2*size of the input file) -
--tab|flag| If the output mode is folder, outputs txt (tab separated) files instead of csv (comma separated) -
--trio|path| Path to a tab separated txt file. Use if you have trio data with unnaffected parents to detect de-novo mutations. Necessary for ACMG PS2 criteria. See the trio wiki page for more information. -
--pp2_percent|0 to 100 int|Threshold for PP2, considering PP2 positive if variant is missense in a gene where more than the threshold are pathogenic missense - default = 80 -
--pp2_min|int| Number of minimum pathogenic missense variants in gene to consider PP2 -
--bp1_percent|0 to 100 int|Threshold for BP1, considering BP1 positive if variant is missense in a gene where less than the threshold are pathogenic missense - default = 15